@@ -9,9 +9,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: __init__.py 1136 2007-02-23 05:25:10Z pronovic $
 # Purpose  : Provides package initialization
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -44,5 +43,5 @@ Architecture Interface, i.e. the same interface that extensions implement.
 # Using 'from CedarBackup2.actions import *' will just import the modules listed
 # in the __all__ variable.
 
-__all__ = [ 'constants', 'collect', 'stage', 'store', 'purge', 'util', 'rebuild', 'validate', ]
+__all__ = [ 'constants', 'collect', 'initialize', 'stage', 'store', 'purge', 'util', 'rebuild', 'validate', ]
 
