@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2007 Kenneth J. Pronovici.
+# Copyright (c) 2004-2007,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: cli.py 935 2009-03-29 18:56:50Z pronovic $
 # Purpose  : Provides command-line interface implementation.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -87,7 +86,8 @@ import getopt
 
 # Cedar Backup modules
 from CedarBackup2.release import AUTHOR, EMAIL, VERSION, DATE, COPYRIGHT
-from CedarBackup2.util import RestrictedContentList, DirectedGraph, PathResolverSingleton
+from CedarBackup2.customize import customizeOverrides
+from CedarBackup2.util import DirectedGraph, PathResolverSingleton
 from CedarBackup2.util import sortDict, splitCommandLine, executeCommand, getFunctionReference
 from CedarBackup2.util import getUidGid, encodePath, Diagnostics
 from CedarBackup2.config import Config
@@ -168,7 +168,7 @@ def cli():
 
    A different error code is returned for each type of failure:
 
-      - C{1}: The Python interpreter version is < 2.3
+      - C{1}: The Python interpreter version is < 2.5
       - C{2}: Error processing command-line arguments
       - C{3}: Error configuring logging
       - C{4}: Error parsing indicated configuration file
@@ -186,12 +186,12 @@ def cli():
    @return: Error code as described above.
    """
    try:
-      if map(int, [sys.version_info[0], sys.version_info[1]]) < [2, 3]:
-         sys.stderr.write("Python version 2.3 or greater required.\n")
+      if map(int, [sys.version_info[0], sys.version_info[1]]) < [2, 5]:
+         sys.stderr.write("Python version 2.5 or greater required.\n")
          return 1
    except:
       # sys.version_info isn't available before 2.0
-      sys.stderr.write("Python version 2.3 or greater required.\n")
+      sys.stderr.write("Python version 2.5 or greater required.\n")
       return 1
 
    try:
@@ -243,6 +243,7 @@ def cli():
    try:
       logger.info("Configuration path is [%s]" % configPath)
       config = Config(xmlPath=configPath)
+      customizeOverrides(config)
       setupPathResolver(config)
       actionSet = _ActionSet(options.actions, config.extensions, config.options, 
                              config.peers, executeManaged, executeLocal)
@@ -375,7 +376,7 @@ class _ActionItem(object):
       logger.debug("Calling action function [%s], execution index [%d]" % (name, self.index))
       self.function(configPath, options, config)
 
-   def _executeHook(self, type, hook):
+   def _executeHook(self, type, hook):  # pylint: disable=W0622,R0201
       """
       Executes a hook command via L{util.executeCommand()}.
       @param type: String describing the type of hook, for logging.
@@ -544,6 +545,7 @@ class _ActionSet(object):
       _ActionSet._validateActions(actions, extensionNames)
       self.actionSet = _ActionSet._buildActionSet(actions, actionMap)
 
+   @staticmethod
    def _deriveExtensionNames(extensions):
       """
       Builds a list of extended actions that are available in configuration.
@@ -555,8 +557,8 @@ class _ActionSet(object):
          for action in extensions.actions:
             extensionNames.append(action.name)
       return extensionNames
-   _deriveExtensionNames = staticmethod(_deriveExtensionNames)
 
+   @staticmethod
    def _buildHookMaps(hooks):
       """
       Build two mappings from action name to configured C{ActionHook}.
@@ -572,8 +574,8 @@ class _ActionSet(object):
             elif hook.after:
                postHookMap[hook.action] = hook
       return (preHookMap, postHookMap)
-   _buildHookMaps = staticmethod(_buildHookMaps)
 
+   @staticmethod
    def _buildFunctionMap(extensions):
       """
       Builds a mapping from named action to action function.
@@ -592,8 +594,8 @@ class _ActionSet(object):
          for action in extensions.actions:
             functionMap[action.name] = getFunctionReference(action.module, action.function)
       return functionMap
-   _buildFunctionMap = staticmethod(_buildFunctionMap)
 
+   @staticmethod
    def _buildIndexMap(extensions):
       """
       Builds a mapping from action name to proper execution index.
@@ -613,25 +615,25 @@ class _ActionSet(object):
       indexMap = {}
       if extensions is None or extensions.actions is None or extensions.actions == []:
          logger.info("Action ordering will use 'index' order mode.")
-         indexMap['rebuild'] = REBUILD_INDEX;
-         indexMap['validate'] = VALIDATE_INDEX;
-         indexMap['initialize'] = INITIALIZE_INDEX;
-         indexMap['collect'] = COLLECT_INDEX;
-         indexMap['stage'] = STAGE_INDEX;
-         indexMap['store'] = STORE_INDEX;
-         indexMap['purge'] = PURGE_INDEX;
+         indexMap['rebuild'] = REBUILD_INDEX
+         indexMap['validate'] = VALIDATE_INDEX
+         indexMap['initialize'] = INITIALIZE_INDEX
+         indexMap['collect'] = COLLECT_INDEX
+         indexMap['stage'] = STAGE_INDEX
+         indexMap['store'] = STORE_INDEX
+         indexMap['purge'] = PURGE_INDEX
          logger.debug("Completed filling in action indices for built-in actions.")
          logger.info("Action order will be: %s" % sortDict(indexMap))
       else:
          if extensions.orderMode is None or extensions.orderMode == "index":
             logger.info("Action ordering will use 'index' order mode.")
-            indexMap['rebuild'] = REBUILD_INDEX;
-            indexMap['validate'] = VALIDATE_INDEX;
-            indexMap['initialize'] = INITIALIZE_INDEX;
-            indexMap['collect'] = COLLECT_INDEX;
-            indexMap['stage'] = STAGE_INDEX;
-            indexMap['store'] = STORE_INDEX;
-            indexMap['purge'] = PURGE_INDEX;
+            indexMap['rebuild'] = REBUILD_INDEX
+            indexMap['validate'] = VALIDATE_INDEX
+            indexMap['initialize'] = INITIALIZE_INDEX
+            indexMap['collect'] = COLLECT_INDEX
+            indexMap['stage'] = STAGE_INDEX
+            indexMap['store'] = STORE_INDEX
+            indexMap['purge'] = PURGE_INDEX
             logger.debug("Completed filling in action indices for built-in actions.")
             for action in extensions.actions:
                indexMap[action.name] = action.index
@@ -679,8 +681,8 @@ class _ActionSet(object):
                logger.error("Extensions configuration is invalid (check for loops).")
                raise ValueError("Unable to determine proper action order due to dependency recursion.")
       return indexMap
-   _buildIndexMap = staticmethod(_buildIndexMap)
 
+   @staticmethod
    def _buildActionMap(managed, local, extensionNames, functionMap, indexMap, preHookMap, postHookMap, peerMap):
       """
       Builds a mapping from action name to list of action items.
@@ -722,8 +724,8 @@ class _ActionSet(object):
                   actionMap[name].append(_ManagedActionItem(index, name, peerMap[name]))
       actionMap['all'] = actionMap['collect'] + actionMap['stage'] + actionMap['store'] + actionMap['purge']
       return actionMap
-   _buildActionMap = staticmethod(_buildActionMap)
 
+   @staticmethod
    def _buildPeerMap(options, peers):
       """
       Build a mapping from action name to list of remote peers.
@@ -754,8 +756,8 @@ class _ActionSet(object):
                         else:
                            peerMap[managedAction] = [ remotePeer, ]
       return peerMap
-   _buildPeerMap = staticmethod(_buildPeerMap)
 
+   @staticmethod
    def _deriveHooks(action, preHookDict, postHookDict):
       """
       Derive pre- and post-action hooks, if any, associated with named action.
@@ -771,8 +773,8 @@ class _ActionSet(object):
       if postHookDict.has_key(action):
          postHook = postHookDict[action]
       return (preHook, postHook)
-   _deriveHooks = staticmethod(_deriveHooks)
 
+   @staticmethod
    def _validateActions(actions, extensionNames):
       """
       Validate that the set of specified actions is sensible.
@@ -794,8 +796,8 @@ class _ActionSet(object):
       for action in NONCOMBINE_ACTIONS:
          if action in actions and actions != [ action, ]:
             raise ValueError("Action [%s] may not be combined with other actions." % action)
-   _validateActions = staticmethod(_validateActions)
 
+   @staticmethod
    def _buildActionSet(actions, actionMap):
       """
       Build set of actions to be executed.
@@ -816,7 +818,6 @@ class _ActionSet(object):
          actionSet.extend(actionMap[action])
       actionSet.sort()  # sort the actions in order by index
       return actionSet
-   _buildActionSet = staticmethod(_buildActionSet)
 
    def executeActions(self, configPath, options, config):
       """
@@ -837,6 +838,7 @@ class _ActionSet(object):
       for actionItem in self.actionSet:
          actionItem.executeAction(configPath, options, config)
 
+   @staticmethod
    def _getRemoteUser(options, remotePeer):
       """
       Gets the remote user associated with a remote peer.
@@ -848,8 +850,8 @@ class _ActionSet(object):
       if remotePeer.remoteUser is None:
          return options.backupUser
       return remotePeer.remoteUser
-   _getRemoteUser = staticmethod(_getRemoteUser)
 
+   @staticmethod
    def _getRshCommand(options, remotePeer):
       """
       Gets the RSH command associated with a remote peer.
@@ -861,8 +863,8 @@ class _ActionSet(object):
       if remotePeer.rshCommand is None:
          return options.rshCommand
       return remotePeer.rshCommand
-   _getRshCommand = staticmethod(_getRshCommand)
 
+   @staticmethod
    def _getCbackCommand(options, remotePeer):
       """
       Gets the cback command associated with a remote peer.
@@ -874,8 +876,8 @@ class _ActionSet(object):
       if remotePeer.cbackCommand is None:
          return options.cbackCommand
       return remotePeer.cbackCommand
-   _getCbackCommand = staticmethod(_getCbackCommand)
 
+   @staticmethod
    def _getManagedActions(options, remotePeer):
       """
       Gets the managed actions list associated with a remote peer.
@@ -887,7 +889,6 @@ class _ActionSet(object):
       if remotePeer.managedActions is None:
          return options.managedActions
       return remotePeer.managedActions
-   _getManagedActions = staticmethod(_getManagedActions)
 
 
 #######################################################################
@@ -1056,9 +1057,9 @@ def _setupLogfile(options):
       logfile = options.logfile
    if not os.path.exists(logfile):
       if options.mode is None: 
-         os.fdopen(os.open(logfile, os.O_CREAT|os.O_APPEND, DEFAULT_MODE)).write("")
+         os.fdopen(os.open(logfile, os.O_RDWR|os.O_CREAT|os.O_APPEND, DEFAULT_MODE), "a+").write("")
       else:
-         os.fdopen(os.open(logfile, os.O_CREAT|os.O_APPEND, options.mode)).write("")
+         os.fdopen(os.open(logfile, os.O_RDWR|os.O_CREAT|os.O_APPEND, options.mode), "a+").write("")
       try:
          if options.owner is None or len(options.owner) < 2:
             (uid, gid) = getUidGid(DEFAULT_OWNERSHIP[0], DEFAULT_OWNERSHIP[1])
@@ -1112,7 +1113,7 @@ def _setupScreenFlowLogging(flowLogger, options):
    @param options: Command-line options.
    """
    formatter = logging.Formatter(fmt=SCREEN_LOG_FORMAT)
-   handler = logging.StreamHandler(strm=SCREEN_LOG_STREAM)
+   handler = logging.StreamHandler(SCREEN_LOG_STREAM)
    handler.setFormatter(formatter)
    if options.quiet:
       handler.setLevel(logging.CRITICAL)  # effectively turn it off
@@ -1326,83 +1327,83 @@ class Options(object):
       """
       if other is None:
          return 1
-      if self._help != other._help:
-         if self._help < other._help:
+      if self.help != other.help:
+         if self.help < other.help:
             return -1
          else:
             return 1
-      if self._version != other._version:
-         if self._version < other._version:
+      if self.version != other.version:
+         if self.version < other.version:
             return -1
          else:
             return 1
-      if self._verbose != other._verbose:
-         if self._verbose < other._verbose:
+      if self.verbose != other.verbose:
+         if self.verbose < other.verbose:
             return -1
          else:
             return 1
-      if self._quiet != other._quiet:
-         if self._quiet < other._quiet:
+      if self.quiet != other.quiet:
+         if self.quiet < other.quiet:
             return -1
          else:
             return 1
-      if self._config != other._config:
-         if self._config < other._config:
+      if self.config != other.config:
+         if self.config < other.config:
             return -1
          else:
             return 1
-      if self._full != other._full:
-         if self._full < other._full:
+      if self.full != other.full:
+         if self.full < other.full:
             return -1
          else:
             return 1
-      if self._managed != other._managed:
-         if self._managed < other._managed:
+      if self.managed != other.managed:
+         if self.managed < other.managed:
             return -1
          else:
             return 1
-      if self._managedOnly != other._managedOnly:
-         if self._managedOnly < other._managedOnly:
+      if self.managedOnly != other.managedOnly:
+         if self.managedOnly < other.managedOnly:
             return -1
          else:
             return 1
-      if self._logfile != other._logfile:
-         if self._logfile < other._logfile:
+      if self.logfile != other.logfile:
+         if self.logfile < other.logfile:
             return -1
          else:
             return 1
-      if self._owner != other._owner:
-         if self._owner < other._owner:
+      if self.owner != other.owner:
+         if self.owner < other.owner:
             return -1
          else:
             return 1
-      if self._mode != other._mode:
-         if self._mode < other._mode:
+      if self.mode != other.mode:
+         if self.mode < other.mode:
             return -1
          else:
             return 1
-      if self._output != other._output:
-         if self._output < other._output:
+      if self.output != other.output:
+         if self.output < other.output:
             return -1
          else:
             return 1
-      if self._debug != other._debug:
-         if self._debug < other._debug:
+      if self.debug != other.debug:
+         if self.debug < other.debug:
             return -1
          else:
             return 1
-      if self._stacktrace != other._stacktrace:
-         if self._stacktrace < other._stacktrace:
+      if self.stacktrace != other.stacktrace:
+         if self.stacktrace < other.stacktrace:
             return -1
          else:
             return 1
-      if self._diagnostics != other._diagnostics:
-         if self._diagnostics < other._diagnostics:
+      if self.diagnostics != other.diagnostics:
+         if self.diagnostics < other.diagnostics:
             return -1
          else:
             return 1
-      if self._actions != other._actions:
-         if self._actions < other._actions:
+      if self.actions != other.actions:
+         if self.actions < other.actions:
             return -1
          else:
             return 1
@@ -1892,7 +1893,7 @@ class Options(object):
       """
       switches = { }
       opts, self.actions = getopt.getopt(argumentList, SHORT_SWITCHES, LONG_SWITCHES)
-      for o,a in opts:  # push the switches into a hash
+      for o, a in opts:  # push the switches into a hash
          switches[o] = a
       if switches.has_key("-h") or switches.has_key("--help"):
          self.help = True
