@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2005 Kenneth J. Pronovici.
+# Copyright (c) 2005,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,13 +25,11 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: sysinfo.py 692 2005-03-10 04:54:11Z pronovic $
 # Purpose  : Provides an extension to save off important system recovery information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
-# This file was created with a width of 132 characters, and NO tabs.
 
 ########################################################################
 # Module documentation
@@ -72,7 +70,7 @@ import logging
 from bz2 import BZ2File
 
 # Cedar Backup modules
-from CedarBackup2.util import executeCommand, changeOwnership
+from CedarBackup2.util import resolveCommand, executeCommand, changeOwnership
 
 
 ########################################################################
@@ -125,8 +123,8 @@ def _dumpDebianPackages(targetDir, backupUser, backupGroup, compress=True):
    """
    Dumps a list of currently installed Debian packages via C{dpkg}.
    @param targetDir: Directory to write output file into.
-   @param backupUser: User which should own the resulting fule.
-   @param backupGroup: Group which should own the resulting fule.
+   @param backupUser: User which should own the resulting file.
+   @param backupGroup: Group which should own the resulting file.
    @param compress: Indicates whether to compress the output file.
    @raise IOError: If the dump fails for some reason.
    """
@@ -137,7 +135,8 @@ def _dumpDebianPackages(targetDir, backupUser, backupGroup, compress=True):
    else:
       (outputFile, filename) = _getOutputFile(targetDir, "dpkg-selections", compress)
       try:
-         result = executeCommand(DPKG_COMMAND, [], returnOutput=False, ignoreStderr=True, doNotLog=True, outputFile=outputFile)[0]
+         command = resolveCommand(DPKG_COMMAND)
+         result = executeCommand(command, [], returnOutput=False, ignoreStderr=True, doNotLog=True, outputFile=outputFile)[0]
          if result != 0:
             raise IOError("Error [%d] executing Debian package dump." % result)
       finally:
@@ -150,8 +149,8 @@ def _dumpPartitionTable(targetDir, backupUser, backupGroup, compress=True):
    """
    Dumps information about the partition table via C{fdisk}.
    @param targetDir: Directory to write output file into.
-   @param backupUser: User which should own the resulting fule.
-   @param backupGroup: Group which should own the resulting fule.
+   @param backupUser: User which should own the resulting file.
+   @param backupGroup: Group which should own the resulting file.
    @param compress: Indicates whether to compress the output file.
    @raise IOError: If the dump fails for some reason.
    """
@@ -162,7 +161,8 @@ def _dumpPartitionTable(targetDir, backupUser, backupGroup, compress=True):
    else:
       (outputFile, filename) = _getOutputFile(targetDir, "fdisk-l", compress)
       try:
-         result = executeCommand(FDISK_COMMAND, [], returnOutput=False, ignoreStderr=True, outputFile=outputFile)[0]
+         command = resolveCommand(FDISK_COMMAND)
+         result = executeCommand(command, [], returnOutput=False, ignoreStderr=True, outputFile=outputFile)[0]
          if result != 0:
             raise IOError("Error [%d] executing partition table dump." % result)
       finally:
@@ -175,15 +175,16 @@ def _dumpFilesystemContents(targetDir, backupUser, backupGroup, compress=True):
    """
    Dumps complete listing of filesystem contents via C{ls -laR}.
    @param targetDir: Directory to write output file into.
-   @param backupUser: User which should own the resulting fule.
-   @param backupGroup: Group which should own the resulting fule.
+   @param backupUser: User which should own the resulting file.
+   @param backupGroup: Group which should own the resulting file.
    @param compress: Indicates whether to compress the output file.
    @raise IOError: If the dump fails for some reason.
    """
    (outputFile, filename) = _getOutputFile(targetDir, "ls-laR", compress)
    try:
       # Note: can't count on return status from 'ls', so we don't check it.
-      executeCommand(LS_COMMAND, [], returnOutput=False, ignoreStderr=True, doNotLog=True, outputFile=outputFile)
+      command = resolveCommand(LS_COMMAND)
+      executeCommand(command, [], returnOutput=False, ignoreStderr=True, doNotLog=True, outputFile=outputFile)
    finally:
       outputFile.close()
    if not os.path.exists(filename):
