@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2008 Kenneth J. Pronovici.
+# Copyright (c) 2004-2008,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: peer.py 852 2008-03-16 23:34:19Z pronovic $
 # Purpose  : Provides backup peer-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -39,7 +38,7 @@
 """
 Provides backup peer-related objects and utility functions.
 
-@sort: LocalPeer, Remote Peer
+@sort: LocalPeer, RemotePeer
 
 @var DEF_COLLECT_INDICATOR: Name of the default collect indicator file.
 @var DEF_STAGE_INDICATOR: Name of the default stage indicator file.
@@ -56,13 +55,12 @@ Provides backup peer-related objects and utility functions.
 import os
 import logging
 import shutil
-import sets
-import re
 
 # Cedar Backup modules
 from CedarBackup2.filesystem import FilesystemList
-from CedarBackup2.util import resolveCommand, executeCommand
+from CedarBackup2.util import resolveCommand, executeCommand, isRunningAsRoot
 from CedarBackup2.util import splitCommandLine, encodePath
+from CedarBackup2.config import VALID_FAILURE_MODES
 
 
 ########################################################################
@@ -110,7 +108,7 @@ class LocalPeer(object):
    # Constructor
    ##############
 
-   def __init__(self, name, collectDir):
+   def __init__(self, name, collectDir, ignoreFailureMode=None):
       """
       Initializes a local backup peer.
 
@@ -125,13 +123,18 @@ class LocalPeer(object):
       @param collectDir: Path to the peer's collect directory 
       @type collectDir: String representing an absolute local path on disk
 
+      @param ignoreFailureMode: Ignore failure mode for this peer
+      @type ignoreFailureMode: One of VALID_FAILURE_MODES
+
       @raise ValueError: If the name is empty.
       @raise ValueError: If collect directory is not an absolute path.
       """
       self._name = None
       self._collectDir = None
+      self._ignoreFailureMode = None
       self.name = name
       self.collectDir = collectDir
+      self.ignoreFailureMode = ignoreFailureMode
 
 
    #############
@@ -172,8 +175,26 @@ class LocalPeer(object):
       """
       return self._collectDir
 
+   def _setIgnoreFailureMode(self, value):
+      """
+      Property target used to set the ignoreFailure mode.
+      If not C{None}, the mode must be one of the values in L{VALID_FAILURE_MODES}.
+      @raise ValueError: If the value is not valid.
+      """
+      if value is not None:
+         if value not in VALID_FAILURE_MODES:
+            raise ValueError("Ignore failure mode must be one of %s." % VALID_FAILURE_MODES)
+      self._ignoreFailureMode = value
+
+   def _getIgnoreFailureMode(self):
+      """
+      Property target used to get the ignoreFailure mode.
+      """
+      return self._ignoreFailureMode 
+
    name = property(_getName, _setName, None, "Name of the peer.")
    collectDir = property(_getCollectDir, _setCollectDir, None, "Path to the peer's collect directory (an absolute local path).")
+   ignoreFailureMode = property(_getIgnoreFailureMode, _setIgnoreFailureMode, None, "Ignore failure mode for peer.")
 
 
    #################
@@ -294,6 +315,7 @@ class LocalPeer(object):
    # Private methods
    ##################
 
+   @staticmethod
    def _copyLocalDir(sourceDir, targetDir, ownership=None, permissions=None):
       """
       Copies files from the source directory to the target directory.
@@ -335,8 +357,8 @@ class LocalPeer(object):
          LocalPeer._copyLocalFile(sourceFile, targetFile, ownership, permissions)
          filesCopied += 1
       return filesCopied
-   _copyLocalDir = staticmethod(_copyLocalDir)
 
+   @staticmethod
    def _copyLocalFile(sourceFile=None, targetFile=None, ownership=None, permissions=None, overwrite=True):
       """
       Copies a source file to a target file.
@@ -392,7 +414,6 @@ class LocalPeer(object):
          os.chown(targetFile, ownership[0], ownership[1])
       if permissions is not None:
          os.chmod(targetFile, permissions)
-   _copyLocalFile = staticmethod(_copyLocalFile)
 
 
 ########################################################################
@@ -436,8 +457,9 @@ class RemotePeer(object):
    # Constructor
    ##############
 
-   def __init__(self, name, collectDir=None, workingDir=None, remoteUser=None, 
-                rcpCommand=None, localUser=None, rshCommand=None, cbackCommand=None):
+   def __init__(self, name=None, collectDir=None, workingDir=None, remoteUser=None, 
+                rcpCommand=None, localUser=None, rshCommand=None, cbackCommand=None,
+                ignoreFailureMode=None):
       """
       Initializes a remote backup peer.
 
@@ -471,6 +493,9 @@ class RemotePeer(object):
       @param cbackCommand: A chack-compatible command to use for executing managed actions
       @type cbackCommand: String representing a system command including required arguments
 
+      @param ignoreFailureMode: Ignore failure mode for this peer
+      @type ignoreFailureMode: One of VALID_FAILURE_MODES
+
       @raise ValueError: If collect directory is not an absolute path
       """
       self._name = None
@@ -483,6 +508,7 @@ class RemotePeer(object):
       self._rshCommand = None
       self._rshCommandList = None
       self._cbackCommand = None
+      self._ignoreFailureMode = None
       self.name = name
       self.collectDir = collectDir
       self.workingDir = workingDir
@@ -491,6 +517,7 @@ class RemotePeer(object):
       self.rcpCommand = rcpCommand
       self.rshCommand = rshCommand
       self.cbackCommand = cbackCommand
+      self.ignoreFailureMode = ignoreFailureMode
 
 
    #############
@@ -671,6 +698,23 @@ class RemotePeer(object):
       """
       return self._cbackCommand
 
+   def _setIgnoreFailureMode(self, value):
+      """
+      Property target used to set the ignoreFailure mode.
+      If not C{None}, the mode must be one of the values in L{VALID_FAILURE_MODES}.
+      @raise ValueError: If the value is not valid.
+      """
+      if value is not None:
+         if value not in VALID_FAILURE_MODES:
+            raise ValueError("Ignore failure mode must be one of %s." % VALID_FAILURE_MODES)
+      self._ignoreFailureMode = value
+
+   def _getIgnoreFailureMode(self):
+      """
+      Property target used to get the ignoreFailure mode.
+      """
+      return self._ignoreFailureMode 
+
    name = property(_getName, _setName, None, "Name of the peer (a valid DNS hostname).")
    collectDir = property(_getCollectDir, _setCollectDir, None, "Path to the peer's collect directory (an absolute local path).")
    workingDir = property(_getWorkingDir, _setWorkingDir, None, "Path to the peer's working directory (an absolute local path).")
@@ -679,6 +723,7 @@ class RemotePeer(object):
    rcpCommand = property(_getRcpCommand, _setRcpCommand, None, "An rcp-compatible copy command to use for copying files.")
    rshCommand = property(_getRshCommand, _setRshCommand, None, "An rsh-compatible command to use for remote shells to the peer.")
    cbackCommand = property(_getCbackCommand, _setCbackCommand, None, "A chack-compatible command to use for executing managed actions.")
+   ignoreFailureMode = property(_getIgnoreFailureMode, _setIgnoreFailureMode, None, "Ignore failure mode for peer.")
 
 
    #################
@@ -870,13 +915,13 @@ class RemotePeer(object):
    # Private methods
    ##################
 
+   @staticmethod
    def _getDirContents(path):
       """
       Returns the contents of a directory in terms of a Set.
       
       The directory's contents are read as a L{FilesystemList} containing only
-      files, and then the list is converted into a C{sets.Set} object for later
-      use.
+      files, and then the list is converted into a set object for later use.
 
       @param path: Directory path to get contents for
       @type path: String representing a path on disk
@@ -888,9 +933,13 @@ class RemotePeer(object):
       contents.excludeDirs = True
       contents.excludeLinks = True
       contents.addDirContents(path)
-      return sets.Set(contents)
-   _getDirContents = staticmethod(_getDirContents)
+      try:
+         return set(contents)
+      except:
+         import sets
+         return sets.Set(contents)
 
+   @staticmethod
    def _copyRemoteDir(remoteUser, localUser, remoteHost, rcpCommand, rcpCommandList, 
                       sourceDir, targetDir, ownership=None, permissions=None):
       """
@@ -961,7 +1010,7 @@ class RemotePeer(object):
       beforeSet = RemotePeer._getDirContents(targetDir)
       if localUser is not None:
          try:
-            if os.getuid() != 0:
+            if not isRunningAsRoot():
                raise IOError("Only root can remote copy as another user.")
          except AttributeError: pass
          actualCommand = "%s %s@%s:%s/* %s" % (rcpCommand, remoteUser, remoteHost, sourceDir, targetDir)
@@ -987,8 +1036,8 @@ class RemotePeer(object):
          if permissions is not None:
             os.chmod(targetFile, permissions)
       return len(differenceSet)
-   _copyRemoteDir = staticmethod(_copyRemoteDir)
 
+   @staticmethod
    def _copyRemoteFile(remoteUser, localUser, remoteHost, 
                        rcpCommand, rcpCommandList,
                        sourceFile, targetFile, ownership=None, 
@@ -1054,7 +1103,7 @@ class RemotePeer(object):
             raise IOError("Target file [%s] already exists." % targetFile)
       if localUser is not None:
          try:
-            if os.getuid() != 0:
+            if not isRunningAsRoot():
                raise IOError("Only root can remote copy as another user.")
          except AttributeError: pass
          actualCommand = "%s %s@%s:%s %s" % (rcpCommand, remoteUser, remoteHost, sourceFile.replace(" ", "\\ "), targetFile)
@@ -1074,8 +1123,8 @@ class RemotePeer(object):
          os.chown(targetFile, ownership[0], ownership[1])
       if permissions is not None:
          os.chmod(targetFile, permissions)
-   _copyRemoteFile = staticmethod(_copyRemoteFile)
 
+   @staticmethod
    def _pushLocalFile(remoteUser, localUser, remoteHost, 
                       rcpCommand, rcpCommandList,
                       sourceFile, targetFile, overwrite=True):
@@ -1125,7 +1174,7 @@ class RemotePeer(object):
             raise IOError("Target file [%s] already exists." % targetFile)
       if localUser is not None:
          try:
-            if os.getuid() != 0:
+            if not isRunningAsRoot():
                raise IOError("Only root can remote copy as another user.")
          except AttributeError: pass
          actualCommand = '%s "%s" "%s@%s:%s"' % (rcpCommand, sourceFile, remoteUser, remoteHost, targetFile)
@@ -1139,8 +1188,8 @@ class RemotePeer(object):
          result = executeCommand(command, [sourceFile.replace(" ", "\\ "), copyTarget])[0]
          if result != 0:
             raise IOError("Error (%d) copying [%s] to remote host." % (result, sourceFile))
-   _pushLocalFile = staticmethod(_pushLocalFile)
 
+   @staticmethod
    def _executeRemoteCommand(remoteUser, localUser, remoteHost, rshCommand, rshCommandList, remoteCommand):
       """
       Executes a command on the peer via remote shell.
@@ -1168,7 +1217,7 @@ class RemotePeer(object):
       actualCommand = "%s %s@%s '%s'" % (rshCommand, remoteUser, remoteHost, remoteCommand)
       if localUser is not None:
          try:
-            if os.getuid() != 0:
+            if not isRunningAsRoot():
                raise IOError("Only root can remote shell as another user.")
          except AttributeError: pass
          command = resolveCommand(SU_COMMAND) 
@@ -1180,8 +1229,8 @@ class RemotePeer(object):
          result = executeCommand(command, ["%s@%s" % (remoteUser, remoteHost), "%s" % remoteCommand])[0]
          if result != 0:
             raise IOError("Command failed [%s]" % (actualCommand))
-   _executeRemoteCommand = staticmethod(_executeRemoteCommand)
 
+   @staticmethod
    def _buildCbackCommand(cbackCommand, action, fullBackup):
       """
       Builds a Cedar Backup command line for the named action.
@@ -1203,5 +1252,4 @@ class RemotePeer(object):
          return "%s --full %s" % (cbackCommand, action)
       else:
          return "%s %s" % (cbackCommand, action)
-   _buildCbackCommand = staticmethod(_buildCbackCommand)
 
