@@ -11,7 +11,6 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 1074 2014-10-03 17:55:34Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -33,8 +32,8 @@ Provides location to maintain version information.
 
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
-COPYRIGHT   = "2004-2011,2013,2014"
-VERSION     = "2.23.3"
-DATE        = "03 Oct 2014"
-URL         = "http://cedar-backup.sourceforge.net/"
+COPYRIGHT   = "2004-2011,2013-2015"
+VERSION     = "2.24.3"
+DATE        = "28 Jul 2015"
+URL         = "https://bitbucket.org/cedarsolutions/cedar-backup2"
 
