@@ -28,7 +28,6 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: test.py 1054 2014-10-01 21:51:59Z pronovic $
 # Purpose  : Run all of the unit tests for the project.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -167,6 +166,7 @@ def main():
       from testcase import amazons3tests
       from testcase import splittests
       from testcase import spantests
+      from testcase import synctests
       from testcase import capacitytests
       from testcase import customizetests
    except ImportError, e:
@@ -226,6 +226,7 @@ def main():
    if args == [] or "encrypt" in args: unittests["encrypt"] = encrypttests.suite()
    if args == [] or "amazons3" in args: unittests["amazons3"] = amazons3tests.suite()
    if args == [] or "span" in args: unittests["span"] = spantests.suite()
+   if args == [] or "sync" in args: unittests["sync"] = synctests.suite()
    if args == [] or "capacity" in args: unittests["capacity"] = capacitytests.suite()
    if args == [] or "customize" in args: unittests["customize"] = customizetests.suite()
    if args != []: print "*** Executing specific tests: %s" % unittests.keys()
